# UserAccessInfo


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**org_ids** | **[str]** | All org_ids user is a member of  | [optional] 
**user_id** | **str** | The unique id of the User to which this record applies.  | [optional] 
**user_ssh_access_info** | [**[UserSSHAccessInfo]**](UserSSHAccessInfo.md) | The matching UserSSHAccessInfo objects | [optional] 
**user_desktop_access_info** | [**[UserDesktopAccessInfo]**](UserDesktopAccessInfo.md) | The matching UserDesktopAccessInfo objects | [optional] 
**user_resource_access_info** | [**[UserResourceAccessInfo]**](UserResourceAccessInfo.md) | The matching UserResourceAccessInfo objects | [optional] 
**user_file_share_access_info** | [**[UserFileShareAccessInfo]**](UserFileShareAccessInfo.md) | The matching UserFileShareAccessInfo objects | [optional] 
**user_launcher_access_info** | [**[UserLauncherAccessInfo]**](UserLauncherAccessInfo.md) | The matching UserLauncherAccessInfo objects | [optional] 
**user_application_access_info** | [**[UserApplicationAccessInfo]**](UserApplicationAccessInfo.md) | The matching UserApplicationAccessInfo objects | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


